@@ -22,6 +22,38 @@ class __TQL:
                 return pickle.load(f)
         except:
             return None
+
+    @staticmethod
+    def save_pkl(data, dest):
+        try:
+            with open(dest, 'data') as f:
+                pickle.dump(data, f)
+        except:
+            return None
+
+    @staticmethod
+    def add_user(username):
+        users = __TQL.load_pkl(__TQL.__qdbpath+"authentification.tql")
+        users.add(username)
+        __TQL.save_pkl(users, __TQL.__qdbpath+"authentification.tql")
+        print(f"{username} added.")
+
+    @staticmethod
+    def delete_user(username):
+        users = __TQL.load_pkl(__TQL.__qdbpath+"authentification.tql")
+        try:
+            users.remove(username)
+            print(f"{username} deleted.")
+        except:
+            print(f'{username} does not exists.')
+        __TQL.save_pkl(users, __TQL.__qdbpath+"authentification.tql")
+        print(f"{username} added.")
+
+    
+    
+
+
+    
         
     @classmethod
     def qdb(cls, f):
